<?php
/**
 * ###############################################
 *
 * SWIFT Framework
 * _______________________________________________
 *
 * @author            Varun Shoor
 *
 * @package           SWIFT
 * @copyright         Copyright (c) 2001-2012, Kayako
 * @license           http://www.kayako.com/license
 * @link              http://www.kayako.com
 *
 * ###############################################
 */

/**
 * The Ticket Display View
 *
 * @author Rahul Bhattacharya
 */
class View_SugarCRMInfo extends SWIFT_View
{

	public function __construct()
	{
		parent::__construct();

		return true;
	}

	/**
	 * Destructor
	 *
	 * @author
	 * @return bool "true" on Success, "false" otherwise
	 */
	public function __destruct()
	{
		parent::__destruct();

		return true;
	}

	/**
	 * Render the User Info
	 *
	 * @param string $_email
	 *
	 * @return bool "true" on Success, "false" otherwise
	 *
	 * @author Rahul Bhattacharya
	 *
	 */
	public function RenderInfo($_email)
	{
		$_SWIFT = SWIFT::GetInstance();

		if (!$this->GetIsClassLoaded()) {
			return false;
		}

		$_sessionId = $this->CreateSugarConnection($_SWIFT);

		$this->RenderUserInfo($this->FetchUserInfo($_sessionId, $_email));

		return true;
	}

	/**
	 * Create connection with sugarcrm rest api
	 *
	 * @param SWIFT Class Object
	 *
	 * @return string $_sugarcrmSessionResponse on Success, "false" otherwise
	 *
	 * @author Rahul Bhattacharya
	 */
	protected function CreateSugarConnection($_SWIFT)
	{
		$this->Load->Library('SugarCRMRestAPI:SugarCRMRestAPIRequest');

		$_sugarcrmUsername = $_SWIFT->Settings->Get('sugarcrm_username');
		$_sugarcrmPassword = $_SWIFT->Settings->Get('sugarcrm_password');
		$this->_url        = $_SWIFT->Settings->Get('sugarcrm_apiurl');

		if (empty($_sugarcrmUsername) || empty($_sugarcrmPassword) || empty($this->_url)) {
			return false;
		} else {
			$_sugarcrmSessionResponse = $this->SugarCRMRestAPIRequest->LoginRequest($_sugarcrmUsername, $_sugarcrmPassword, $this->_url);

			return $_sugarcrmSessionResponse;
		}
	}

	/**
	 * Render the SugarCrm User information
	 *
	 * @param string $_sessionId
	 * @param string $_userEmail
	 *
	 * @return object sugarcrm api response
	 *
	 * @author Rahul Bhattacharya
	 */
	protected function FetchUserInfo($_sessionId, $_userEmail)
	{
		$_leadId = $this->GetLeadId($_sessionId, $_userEmail);

		if ($_leadId !== null) {
			$_getEntryListParameters = array(
				'session'       => $_sessionId,
				'module_name'   => 'Leads',
				'query'         => "leads.id='" . $_leadId . "'",
				'order_by'      => "",
				'offset'        => '0',
				'select_fields' => array(
					'id', 'name', 'assigned_user_name', 'modified_by_name', 'created_by_name', 'date_entered', 'date_modified', 'created_by', 'description', 'deleted',
					'salutation',
					'first_name', 'last_name', 'title', 'department', 'do_not_call', 'phone_home', 'phone_mobile', 'phone_work', 'phone_other', 'phone_fax', 'email1', 'email2',
					'primary_address_street', 'primary_address_city', 'primary_address_state', 'primary_address_postalcode', 'primary_address_country', 'alt_address_street',
					'alt_address_city', 'alt_address_street', 'alt_address_city', 'alt_address_state', 'alt_address_postalcode', 'alt_address_country', 'assistant',
					'assistant_phone', 'lead_source', 'account_name', 'opportunity_role_fields', 'report_to_name', 'birthdate', 'campaign_name', 'modified_user_name',
				),
			);

			$_requestParameters = array(
				'url'        => $this->_url,
				'method'     => 'get_entry_list',
				'parameters' => $_getEntryListParameters
			);

			return $this->SugarCRMRestAPIRequest->CurlResponse($_requestParameters)->entry_list;
		}

		return null;
	}

	/**
	 * Render the SugarCrm Lead Id
	 *
	 * @param string $_sessionId
	 * @param string $_userEmail
	 *
	 * @return object sugarcrm api response
	 *
	 * @author Rahul Bhattacharya
	 */
	protected function GetLeadId($_sessionId, $_userEmail)
	{
		$_leadId = null;

		$_getEntryListParameters = array(
			'session'                   => $_sessionId,
			'module_name'               => 'Leads',
			'query'                     => "",
			'order_by'                  => "",
			'offset'                    => '0',
			'select_fields'             => array(
				'id',
				'email1',
			),
			'link_name_to_fields_array' => array(),
			'max_results'               => '999',
		);

		$_requestParameters = array(
			'url'        => $this->_url,
			'method'     => 'get_entry_list',
			'parameters' => $_getEntryListParameters
		);

		$leadsResponse = $this->SugarCRMRestAPIRequest->CurlResponse($_requestParameters)->entry_list;

		foreach ($leadsResponse as $_key => $_val) {
			if ($_val->name_value_list->email1->value == $_userEmail) {
				$_leadId = $_val->name_value_list->id->value;
				break;
			}
		}

		return $_leadId;
	}

	/**
	 * Render User Information
	 *
	 * @param object $_userObject
	 *
	 * @return bool "true" on Success, "false" otherwise
	 *
	 * @author Rahul Bhattacharya
	 *
	 */
	public function RenderUserInfo($_userObject)
	{
		$_SWIFT = SWIFT::GetInstance();

		if (!$this->GetIsClassLoaded()) {
			return false;
		}

		$_renderHTML = '<table width="100%" cellspacing="0" cellpadding="4" border="0">';
		$_renderHTML .= '<tr>
							<td valign="middle" align="left" class="gridtabletitlerow" width="20%" colspan="4">
								<img src="' . $_SWIFT::Get('swiftpath') . SWIFT_APPS_DIRECTORY . '/sugarcrm/themes/__cp/images/icon_doublearrows.gif' . '" align="absmiddle" border="0"> Contact Information
							</td>
						 </tr>';

		if (!sizeof($_userObject)) {
			$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="25%" colspan="4">Information not available.</td>
                         </tr>';

			$_renderHTML .= '</table>';

			echo $_renderHTML;

			return false;
		}

		$_userObject = $_userObject[0];

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Name :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . ucwords($_userObject->name_value_list->name->value) . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="50%" colspan="2"></td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Title :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->title->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Department :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->department->value . '</td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Primary Email :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->email1->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Secondary Email :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->email2->value . '</td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Assigned User Name :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->assigned_user_name->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Modified By Name :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->modified_by_name->value . '</td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Created By :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->created_by_name->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Date Entered :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->date_entered->value . '</td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="50%" colspan="2">
							    <fieldset id="primary_address">
							        <legend>Primary Address</legend>
							        <table width="100%" cellspacing="0" cellpadding="4" border="0">
										<tr>
											<td valign="middle" align="left" width="20%"><strong>Address :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->primary_address_street->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>City :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->primary_address_city->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>State :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->primary_address_state->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>Postal Code :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->primary_address_postalcode->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>Country :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->primary_address_country->value . '</td>
										</tr>
							        </table>
							    </fieldset>
							 </td>
							 <td valign="middle" align="left" class="tablerow1" width="50%" colspan="2">
							    <fieldset id="other_address">
							        <legend>Other Address</legend>
							        <table width="100%" cellspacing="0" cellpadding="4" border="0">
										<tr>
											<td valign="middle" align="left" width="20%"><strong>Address :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->alt_address_street->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>City :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->alt_address_city->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>State :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->alt_address_street->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>Postal Code :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->alt_address_postalcode->value . '</td>
										</tr>
										<tr>
											<td valign="middle" align="left" width="20%"><strong>Country :</strong></td>
											<td valign="middle" align="left" width="30%">' . $_userObject->name_value_list->alt_address_country->value . '</td>
										</tr>
							        </table>
							    </fieldset>
							 </td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Office Phone :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->phone_work->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Home Phone :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->phone_home->value . '</td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Mobile :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->phone_mobile->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Fax :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->phone_fax->value . '</td>
                         </tr>';

		$_renderHTML .= '<tr class="tablerow1_tr">
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Account Name :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->account_name->value . '</td>
							 <td valign="middle" align="left" class="tablerow1" width="20%"><strong>Lead Source :</strong></td>
							 <td valign="middle" align="left" class="tablerow1" width="30%">' . $_userObject->name_value_list->lead_source->value . '</td>
                         </tr>';

		$_renderHTML .= '</table>';

		echo $_renderHTML;

		return true;
	}
}